#!/usr/bin/python
#-*- coding=utf-8 -*-
#
# Author: Shizhengxian
# DateTime: Tues, Jun 10 2014 16:32:32
#

import os
import sys
import re

#-- 导入Parser_LPMT类 --#
sys.path.append( r'.');
from Parser_LPMT import Parser_LPMT


class Check_LPMT:
    #----------------------------------------------------------------#
    #-@brief: 获取系统（syslog）下执行错误的日志信息
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def check_sys_log_error( self) :
        '''函数返回值为[{"date":None, "time"=None, "user":None",
           "doit":None,"msg":None},{...}]这样的列表
        '''
        root_list = [];

        #-- 生成Parser_LPMT类实例 --#
        pl = Parser_LPMT();
        ret_list  = pl.parser_all_sys_log();

        #-- 检测包含的关键字: failed | Failed | error | Error | ERROR --#
        m_pat_keys = 'failed|Failed|error|Error|ERROR'

        #-- 把错误信息放入root_list列表中 --#
        while len( ret_list) :
            tmp_dict = ret_list.pop();
            tmp_msg  = tmp_dict.get('msg');
            #print tmp_msg;
            m_ret = re.search( m_pat_keys, tmp_msg);
            if m_ret is not None :
                root_list.append( tmp_dict);

        return root_list;
    #-- END OF FUNCTION: check_sys_log_error --#


    #----------------------------------------------------------------#
    #-@brief: 获取系统（syslog）下执行的警告日志信息
    #-
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def check_sys_log_warn( self) :
        '''函数返回值为[{"date":None, "time"=None, "user":None",
           "doit":None,"msg":None},{...}]这样的列表
        '''
        root_list = [];

        #-- 生成Parser_LPMT类实例 --#
        pl = Parser_LPMT();
        ret_list  = pl.parser_all_sys_log();

        #-- 检测包含的关键字: failed | Failed | error | Error | ERROR --#
        m_pat_keys = '<warn>|WARNING|Warning|warning'

        #-- 把错误信息放入root_list列表中 --#
        while len( ret_list) :
            tmp_dict = ret_list.pop();
            tmp_msg  = tmp_dict.get('msg');
            #print tmp_msg;
            m_ret = re.search( m_pat_keys, tmp_msg);
            if m_ret is not None :
                root_list.append( tmp_dict);

        return root_list;
    #-- END OF FUNCTION: check_sys_log_warn --#

    #----------------------------------------------------------------#
    #-@brief: 根据关键字在输入列表中查找匹配的元素，并返回与输入列表结构
    #-        一致，元素结构一致的列表.
    #-
    #-@param: in_list, 输入的数据源列表.
    #-@param: key, 查找的关键字源.
    #- 
    #-@return: 日志列表集合，元素项为字典.
    #----------------------------------------------------------------#
    def check_match_keywords( self, in_list, key) :
        root_list = [];

        #-- 清除前后空格,如果为空，则返回全部 --#
        tmp_key = key.strip();
        if len( tmp_key) < 1:
            root_list.extend( in_list);

            return root_list;

        #-- in_list必须为列表 --#
        if type( in_list) is list :
            for item_list in in_list :
                #-- 列表元素必须为字典类型 --#
                if type( item_list) is dict :
                    tmp_item_list = item_list.values();
                    
                    if tmp_item_list is None :
                        continue;

                    #-- 遍历内容是否有匹配key的 --#
                    for tmp_str in tmp_item_list :
                        if tmp_str is None :
                            continue;
                        if tmp_str.find( tmp_key) != -1 :
                            #-- 查找成功，插入到列表返回列表中 --#
                            root_list.append( item_list);
                            #-- 退出查找匹配循环 --#
                            break;

        #-- 成功返回包含元素的列表，失败返回[] --#
        return root_list;
    #-- END OF FUNCTION: check_match_keywords --#



#if __name__=='__main__' :
#    cl = Check_LPMT()
#    ret_list = cl.check_sys_log_error();
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#    ret_list = cl.check_sys_log_warn();
#    for i in range( len( ret_list)) :
#        print ret_list[i];
#
#    pl = Parser_LPMT();
#    ret_list = pl.parser_all_ufw_log();
#    tmp_list = cl.check_match_keywords( ret_list, '80' );
#    for i in range( len( tmp_list)) :
#        print tmp_list[i];

