#!/usr/bin/python
#-*- coding=utf-8 -*-
#
# Author: Shizhengxian
# DateTime: Fri, May 30 2014 09:09:32 GMT
#
# M_Date: Mon, 16 Jun 2014 11:20:12
# Modify: 添加英文月份转换成数值月份接口 gi_month_to_numeri.
#       : 添加输出临时日志文件接口 gi_lpmt_error_log.
#

import re
import os
import gzip
import time


#--------------------------Class: Gen_inter -------------------------#
class Gen_Inter:
    #----------------------------------------------------------------#
    #-@brief: 将压缩过的日志文件解压到tmp目录下，最后返回文件路径.
    #-
    #-@param: file 文件名，为gz后缀的tar压缩文件.
    #-
    #-@return: 返回解压后的文件路径.
    #----------------------------------------------------------------#
    def gi_uncompress_gz( self, path_name) :
        tmp_file ="";
        tmp_dir  = '/tmp/';
        b_name   = os.path.basename( path_name);
        gz_idx   = b_name.rfind('.gz');
        
        #-- 如果不是.gz后缀，退出 --#
        if gz_idx <= 0 :
            return tmp_file;

        #-- 获取去掉gz后缀过后的文件名 --#
        sub_gz = b_name[ 0 : gz_idx];

        try :
            #-- 开始解压gz文件，并存放到/tmp/目录下 --#
            gz_stream   = gzip.open( path_name, 'rb');
            tmp_file_fd = open( tmp_dir + sub_gz, 'w');

            #-- 读取压缩数据保存到临时文件中 --#
            tmp_file_fd.write( gz_stream.read());

            tmp_file = tmp_dir + sub_gz;

            #-- 记得关闭文件 --#
            gz_stream.close();
            tmp_file_fd.close();
                
        except Exception, e :
            tmp_file = "";
            #print e.message;

        return tmp_file;
    #-- END OF FUNCTION gi_uncompress_gz --#


    #----------------------------------------------------------------#
    #-@brief: 在/var/log/目录下获取相同的日志文件名称，包含gz文件.
    #-
    #-@param: pat 查找的匹配模式条件.
    #-@param: d_path 查找的目标目录，默认为'/var/log/',必须加‘/’符结尾.
    #-
    #-@return: 返回文件集合列表，包含路径.
    #----------------------------------------------------------------#
    def gi_search_same_f( self, pat, d_path='/var/log/') :
        file_list = [];
        try :
            #-- 遍历目录查找匹配pat的文件名 --#
            for f in os.listdir( d_path) :
                m_ret = re.search( pat, f);
                if m_ret is not None :
                    file_list.append( d_path + f);

        except Exception, e :
            file_list = [];
            #print e.message;
        file_list.sort();
        return file_list;
    #-- END OF FUNCTION gi_search_same_f --#


    #----------------------------------------------------------------#
    #-@brief: 获取当年本地时间的年份.
    #-
    #-@return: 返回年份
    #----------------------------------------------------------------#
    def gi_get_year( self) :
        year = "";
        year = time.strftime("%Y", time.localtime( time.time()));

        return year;
    #-- END OF FUNCTION gi_get_year --#


    #----------------------------------------------------------------#
    #-@brief: 将英文月份转为数值，并返回.
    #-
    #-@return: 返回数值表示的月份
    #----------------------------------------------------------------#
    def gi_month_to_numeri( self, month) :
        month_dict = {'Jan':'1', 'Feb':'2', 'Mar':'3', 'Apr':'4', 'May':'5','Jun':'6', 
                      'Jul':'7', 'Aug':'8', 'Sep':'9', 'Oct':'10', 'Nov':'11', 'Dec':'12'
                     };

        #-- 获取月份对应的数值 --#
        return month_dict.get( month.strip());

    
    #----------------------------------------------------------------#
    #-@brief: 输出日志分析管理工具的错误日志到/var/log/lpmt_error.log
    #-
    #-@return: 无
    #----------------------------------------------------------------#
    def gi_lpmt_error_log( self, err_msg) :
        date_time  = time.strftime('%F %X', time.localtime( time.time()) );

        try :
            #-- 打开日志文件 --#
            log_stream = open( '/tmp/lpmt_error.log', 'a+');
            
            #-- 记录错误的日志 --#
            date_time_msg = date_time + ' ==>> ' + err_msg + '\n';
            log_stream.write( date_time_msg);

            log_stream.close();
        except :
            pass;
