#!/usr/bin/python3
# -*- coding:utf-8 -*-
"""Receiver related functionality."""
from logging import exception
from genericpath import exists
import dbus
import dbus.service
import dbus.glib
import _thread
import os
import sys
import zipfile
import pwd

import gi
gi.require_version("Gtk", "3.0")
from gi.repository import GObject

DBUS_PATH='/com/nfs/LpmtService'
DBUS_NAME='com.nfs.LpmtService'
DBUS_INTERFACES='com.nfs.LpmtService'


class LpmtDbusService(dbus.service.Object):
    """Reciever class."""

    loop = None

    def __init__(self, bus_name, object_path, loop):
        """Initialize the DBUS service object."""
        dbus.service.Object.__init__(self, bus_name, object_path)
        self.loop = loop

    @dbus.service.method(DBUS_INTERFACES, in_signature='ssas', out_signature='s')
    def exportLogs(self, user_name, zip_name, src_dirs):
        src_dirs_str="#".join(src_dirs)
        print(src_dirs_str)
        try:
            _thread.start_new_thread(self.zip_dir, (user_name, zip_name, src_dirs_str))
        except:
            return "fail"
        return "exporting"

    @dbus.service.signal(DBUS_INTERFACES)
    def exportLogsSuccess(self):
        #print("dbus service export logs success")
        pass

    @dbus.service.signal(DBUS_INTERFACES)
    def exportLogsFailed(self):
        #print("dbus service export logs failed")
        pass


    def zip_dir(self, user_name, zip_filename, src_path_list):
        for src_path in src_path_list.split("#"):
            if (not os.path.isdir(src_path)):
                continue
            #(save_dir,_)=os.path.split(dest_path)
            save_dir="/tmp"
            if not os.path.isdir(save_dir):
                os.makedirs(save_dir)
    
            zip_list = []
    
            for src_path in src_path_list.split("#"):
                for root,dirs,files in os.walk(src_path):
                    for file_item in files:
                        zip_list.append(os.path.join(root,file_item))
                    for dir_item in dirs:
                        zip_list.append(os.path.join(root,dir_item))
    
            zf = zipfile.ZipFile(os.path.join(save_dir, zip_filename),'w',zipfile.ZIP_DEFLATED, allowZip64=True)
    
            for tar in zip_list:
                try:
                    if not tar in src_path_list.split("#"):
                        zf.write(tar,tar)
                    else:
                        zf.write(tar) 
                except Exception:
                    continue

            zf.close()
        
        if exists(os.path.join(save_dir, zip_filename)):
            os.chown(os.path.join(save_dir, zip_filename), pwd.getpwnam(user_name).pw_uid, pwd.getpwnam(user_name).pw_gid);
        
        if os.path.isfile(os.path.join(save_dir, zip_filename)):
            self.exportLogsSuccess()
        else:
            self.exportLogsFailed()
        return



loop = GObject.MainLoop()

#bus = dbus.SessionBus()
sys_bus = dbus.SystemBus()

bus_name = dbus.service.BusName(DBUS_NAME, bus=sys_bus)

obj = LpmtDbusService(bus_name, DBUS_PATH, loop)

loop.run()
